@@ -6,7 +6,7 @@ import os
 from termcolor import colored, cprint
 
 import subprocess
-from subprocess import call, check_output
+from subprocess import call, check_output, STDOUT
 
 import api
 import repl
@@ -32,7 +32,7 @@ def introduce():
     l(config['introduction'], 'green')
 
 
-def task():
+def show_task():
     """ Informs the user of their current task."""
     task = api.get_task()
     l(task['instruction'], 'cyan')
@@ -46,7 +46,7 @@ def start(name):
         command = 'git clone {} .'.format(url)
     else:
         command = 'git clone {}'.format(url)
-        l('Enter `cd {} && lrn resume` to get started.'.format(name))
+        l('Enter `cd learn-{} && lrn resume` to get started.'.format(name))
         exit(0)
 
     dev_null = open(os.devnull, 'w')
@@ -58,7 +58,7 @@ def start(name):
     command = 'git checkout {}'.format(branch)
     call(command.split(), stdout=dev_null, stderr=subprocess.STDOUT)
     introduce()
-    task()
+    show_task()
     start_repl()
 
 
@@ -110,16 +110,33 @@ def progress():
         print('\n')
 
 def resume():
-    task()
+    show_task()
     repl.repl()
 
 def next_task():
     # find how many tasks in this lesson
     config = api.get_local_config()
     branch = api.get_branch()
-    __import__('ipdb').set_trace()
+    for index, lesson in enumerate(config['lessons']):
+        if lesson['branch'] == branch:
+            break # we have the right lesson
+
+    task_length = len(lesson['tasks'])
     task = api.get_lrn_task()
-    api.set_lrn_task(task + 1)
+    if task <= task_length:
+        api.set_lrn_task(task + 1)
+        show_task()
+    else:
+        congrats = lesson['completion']
+        l(congrats, 'green')
+        api.set_lrn_task(0)
+        # stash changes
+        call('git stash'.split(), stdout=open('/dev/null', 'w'), stderr=STDOUT)
+        # get next branch
+        next_branch = config['lessons'][index + 1]['branch']
+        call('git checkout {}'.format(next_branch), stdout=open('/dev/null', 'w'), stderr=STDOUT)
+        show_task()
+
 
 def main():
     if args.command == 'list':
@@ -141,6 +158,17 @@ def main():
         print('!')
 
 if __name__ == '__main__':
+
+    help_message = 'Need to add arguments for lrn, possible arguments:\n\n' + ...
+                    '\tlist     ----  Gives a list of all available tutorials.\n' + ...
+                    '\tstart    ----  Starts a lesson.\n' + ...
+                    '\tprogress ----  Displays your lesson progress in a tutorial\n' + ...
+                    '\thint     ----  Gives a hint for the current problem\n' + ...
+                    '\tresume   ----  Resumes the tutorial after user exits\n' + ...
+                    '\tnext     ----  Advances to the next lesson\n'
+    if (len(sys.argv) == 1):
+        print(help_message)
+        exit(0)
     description = 'lrn -- the interactive tutorial platform'
     parser = argparse.ArgumentParser(description=description)
     parser.add_argument('command', help='The action to take (list, start, et cetera)')
